Method: Role::ActivitiesController#options

Defined in:
app/controllers/lesli_guard/role/activities_controller.rb

#optionsJson

Returns Json that contains all the information needed to create a new role_activity.

Examples:

# Executing this controller's action from javascript's frontend
this.http.get('127.0.0.1/house/options/projects')

Returns:

  • (Json)

    Json that contains all the information needed to create a new role_activity



59
60
61
# File 'app/controllers/lesli_guard/role/activities_controller.rb', line 59

def options
    respond_with_successful(Role::Activity.options(current_user, @query))
end